package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````]18``#0```"0@0````0`!30`(``)
M`"@`&P`:``$``'!8?```6'P``%A\```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$```````````````````!D?```9'P```4```````$`
M`0```*Q]``"L?0$`K'T!`)0"``"H$@``!@```````0`"````M'T``+1]`0"T
M?0$`$`$``!`!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DK'T`
M`*Q]`0"L?0$`5`(``%0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`9UX_H%251J?@M\I+%RK+8EJ&U=8$
M````$`````$```!'3E4```````,````"`````````!$```!,````"`````@`
M```!D!`$)4`$@"B```6@AE"$@`$```LH!(PXH!)%B@``"$P```!-````4```
M`%0```!5````70```%X```!?````80```&(```!D````90```&8```!G````
M:@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+,!BV]K"4/69Z_,9D)%
MU>R)!W#3#13BGMK-XYXS8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[
M20``````````````````````````+!(````````#``L```````"``0``````
M`P`6`$`"`````````````!(```#A`@`````````````2````M0(`````````
M````(@```/H"`````````````!$```"G`P`````````````2`````0``````
M````````(````)P!`````````````!(```"4`@`````````````2````T@(`
M````````````$@```/@``````````````!(````6`P`````````````1````
M6P(`````````````$@```%P!`````````````!(```!'`@`````````````2
M````=```````````````$@```/,``````````````!(```!B`@``````````
M```2````)`(`````````````$@```.H!`````````````!(````$`P``````
M```````2````^P$`````````````$@````@"`````````````!(```#1````
M```````````1````3@$`````````````$@```+,``````````````!$````<
M`0`````````````2````FP(`````````````$@```(T"`````````````!$`
M``"*`0`````````````2````L@$`````````````$@```'<!````````````
M`!(```![`@`````````````2````E0$`````````````$@```(,!````````
M`````!(```#H`@`````````````2````*@$`````````````$@```!T`````
M`````````"`````=`@`````````````2````U`$`````````````$@```#("
M`````````````!(```!4```````````````2````I`(`````````````$@``
M`(,``````````````!(```"A`0`````````````2````Q`(`````````````
M$@```(\``````````````!(```!#`0`````````````2`````@(`````````
M````$@```#D"`````````````!(````)`0`````````````2````1@``````
M````````$@```/T``````````````!(```!L`0`````````````2````30(`
M````````````$@```,```````````````!(````6`@`````````````2````
MV@(`````````````$@```-P``````````````!(````K`@`````````````2
M````8P``````````````$@```/L"`````````````"$```"K`@``````````
M```2````I```````````````$@```#H!`````````````!(````L````````
M```````@````_`(`````````````$0```(,"`````````````!(```#9`0``
M```````````2````$`(`````````````$@```,X!`````````````!(```!P
M`@`````````````2````X0$`````````````$@```+H!`````````````!(`
M``#$`P``5)`!```````0`!<`L`,``%$M`````0``$@`-`.@#``"A)0``Z`4`
M`!(`#0#U`@``.14``+P!```2``T`=@,``$T>```$````$@`-`(<#``!`@`$`
M`````!``%P"$!```41X``-`!```2``T`N@0``(DK``#(`0``$@`-`'`$``!`
M@`$``````!``%P#/`P``(2```!8````2``T`]0,``&$Z``#6````$@`-``T$
M``!0/```!````!$`#P!,!```5)`!```````0`!<`400``%20`0``````$``7
M`'P$``!M'0``.````!(`#0"1!```P20``.`````2``T`HP0``#DD``!X````
M$@`-```$````@`$``````!``%@#<`P``.2```!0````2``T`O`,``$"``0``
M````$``6`$($```\@`$`!````!$`%@!F`P``-3P```(````2``T`,@0``/4[
M``!`````$@`-``8$``#U%@```````!(`#0"Q!```Z3D``'@````2``T``@0`
M``"``0``````(``6`)4#``"Q)```$````!(`#0##`P``5)`!```````0`!<`
M'`0``*4=``"H````$@`-`&8$```Y.P``O````!(`#0!9!```32```.P#```2
M``T``%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?
M7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V
M;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`%!E
M<FQ?8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E
M<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP
M=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`;W!E;C8T`')E860`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`'!T:')E
M861?9V5T<W!E8VEF:6,`8VQO<V4`97AI=`!S=')N8VUP`&-L;W-E9&ER`%]?
M<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M
M8VAR`&=E='!I9`!S=')D=7``<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`'-T<F-H<@!R96%D9&ER-C0`7U]C>&%?9FEN86QI>F4`7U]S<')I;G1F
M7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T7VUA:6X`
M7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8G!E<FPN<V\N-2XS,@!L:6)P=&AR96%D+G-O+C``;&EB8RYS;RXV`&QD
M+6QI;G5X+6%R;6AF+G-O+C,`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R96YT
M7V5X96,`7U]B<W-?<W1A<G1?7P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I
M9`!P87)?8VQE86YU<`!?961A=&$`7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE
M`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S
M=&%R=`!?24]?<W1D:6Y?=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`7U]L
M:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?
M96YV`'-H85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O
M9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'-H85]I;FET`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0``````````@`"``(``@`"
M`````P`"``(``@`$``(````"```````"``(``@`"``(``@````````````(`
M`@````,````"``,``@`"```````"``(``@````(````#``(```````(``@``
M``````````(````"``(````"`````@`"``````````(``@`"``(``P`"``(`
M`P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0!2`P``$````"`````4:6D-```$`-`$
M`````````0`!`#@#```0````(````!1I:0T```,`T`0````````!``$`2`,`
M`!``````````%&EI#0```@#0!````````*Q]`0`7````L'T!`!<```#$?P$`
M%P```.A_`0`7````\'\!`!<````$@`$`%P````R``0`7````$(`!`!<````8
M@`$`%P```!R``0`7````((`!`!<````D@`$`%P```"B``0`7````,(`!`!<`
M```T@`$`%P```#R``0`7````R'\!`!4%``#,?P$`%0@``-!_`0`5#0``U'\!
M`!4/``#8?P$`%1D``-Q_`0`5&P``X'\!`!4>``#D?P$`%2<``.Q_`0`5-```
M]'\!`!4^``#X?P$`%4,``/Q_`0`51```T'X!`!8#``#4?@$`%@0``-A^`0`6
M!0``W'X!`!8'``#@?@$`%@D``.1^`0`6"@``Z'X!`!8+``#L?@$`%@P``/!^
M`0`6#@``]'X!`!80``#X?@$`%A$``/Q^`0`6$@```'\!`!83```$?P$`%A0`
M``A_`0`6%0``#'\!`!86```0?P$`%A<``!1_`0`6&```&'\!`!8:```<?P$`
M%AP``"!_`0`6'0``)'\!`!8?```H?P$`%B```"Q_`0`6(0``,'\!`!8B```T
M?P$`%B,``#A_`0`6)```/'\!`!8E``!`?P$`%B8``$1_`0`6)P``2'\!`!8H
M``!,?P$`%BD``%!_`0`6*@``5'\!`!8K``!8?P$`%BP``%Q_`0`6+0``8'\!
M`!8N``!D?P$`%B\``&A_`0`6,```;'\!`!8Q``!P?P$`%C(``'1_`0`6,P``
M>'\!`!8U``!\?P$`%C8``(!_`0`6-P``A'\!`!8X``"(?P$`%CD``(Q_`0`6
M.@``D'\!`!8[``"4?P$`%CP``)A_`0`6/0``G'\!`!9```"@?P$`%D$``*1_
M`0`60@``J'\!`!9%``"L?P$`%D8``+!_`0`61P``M'\!`!9(``"X?P$`%DD`
M`+Q_`0`62@``P'\!`!9+```(0"WI00$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E
M?&P!``#&C^(6RHSB?/R\Y0#&C^(6RHSB=/R\Y0#&C^(6RHSB;/R\Y0#&C^(6
MRHSB9/R\Y0#&C^(6RHSB7/R\Y0#&C^(6RHSB5/R\Y0#&C^(6RHSB3/R\Y7A'
M_><`QH_B%LJ,XD#\O.4`QH_B%LJ,XCC\O.4`QH_B%LJ,XC#\O.4`QH_B%LJ,
MXBC\O.4`QH_B%LJ,XB#\O.4`QH_B%LJ,XAC\O.5X1_WG`,:/XA;*C.(,_+SE
M`,:/XA;*C.($_+SE>$?]YP#&C^(6RHSB^/N\Y0#&C^(6RHSB\/N\Y0#&C^(6
MRHSBZ/N\Y0#&C^(6RHSBX/N\Y0#&C^(6RHSBV/N\Y0#&C^(6RHSBT/N\Y0#&
MC^(6RHSBR/N\Y0#&C^(6RHSBP/N\Y0#&C^(6RHSBN/N\Y0#&C^(6RHSBL/N\
MY0#&C^(6RHSBJ/N\Y0#&C^(6RHSBH/N\Y0#&C^(6RHSBF/N\Y0#&C^(6RHSB
MD/N\Y0#&C^(6RHSBB/N\Y0#&C^(6RHSB@/N\Y0#&C^(6RHSB>/N\Y0#&C^(6
MRHSB</N\Y0#&C^(6RHSB:/N\Y0#&C^(6RHSB8/N\Y0#&C^(6RHSB6/N\Y0#&
MC^(6RHSB4/N\Y0#&C^(6RHSB2/N\Y0#&C^(6RHSB0/N\Y7A'_><`QH_B%LJ,
MXC3[O.4`QH_B%LJ,XBS[O.4`QH_B%LJ,XB3[O.4`QH_B%LJ,XAS[O.4`QH_B
M%LJ,XA3[O.4`QH_B%LJ,X@S[O.4`QH_B%LJ,X@3[O.4`QH_B%LJ,XOSZO.4`
MQH_B%LJ,XO3ZO.4`QH_B%LJ,XNSZO.4`QH_B%LJ,XN3ZO.4`QH_B%LJ,XMSZ
MO.4`QH_B%LJ,XM3ZO.4`QH_B%LJ,XLSZO.4`QH_B%LJ,XL3ZO.4`QH_B%LJ,
MXKSZO.4`QH_B%LJ,XK3ZO.4`QH_B%LJ,XJSZO.4`QH_B%LJ,XJ3ZO.4`QH_B
M%LJ,XISZO.4`QH_B%LJ,XI3ZO.4`QH_B%LJ,XHSZO.5PM5M-B+!;2WU$6TS-
MZ000!:@#D@2I`ZI\1.M8&V@'DT_P``/_]T+O5$I52Z)8X%@11@+P9?M32^-8
M'7@`+6O044OD6"!H__?6[P-&(&B3^,8C0O`"`H/XQB/_]\SO!9V0^,8S*AT#
M-4/P`0.R\8!/@/C&,W/2D`#_]]SN0TI$2WI$!)Q[1!)H(6B"8$%*6&!Z1`6;
MPF!`2@$K`6!Z1$)@7]V;`"$=!.L##@#Q#`Q1^`1+3/@$3W%%^=$,,S=.`"$`
MD2I&?D3!4#5)`T9Y1/!H__<P[P1&>+,R30:N?43H:/_WBNXP2#%&>$0`\._X
M0+,N2WM$V&C_]U+N__<0[RQ*'$MZ1--8&F@'FUI`3_```RG1($8(L'"]__>`
M[B5*>D308!"S__<T[A=+Y%@@:/_W8N^`^'U7A>?P:/_W,N\$1LKGJ&@0L0'P
M9_O1YQI(,49X1`#PN_BH8``HR=#SY__W".\0(ZKG__<N[@$@__>2[H!I`0`,
M`0``<&D!`"@!```P`0``&`$``!0!``"`:@$`A&H!`$@J```X*@``1&H!`/T&
M```L:@$`N"<``!9J`0"&:`$`ZFD!`/`F``!/\``+3_``#@*\:D8$M`&TW_@D
MH`BCFD3?^"#`6O@,P$WX!,T&2UKX`S`&2%KX``#_]SKN__?H[IAG`0```0``
M)`$``"P!```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$6___J>&<!`"`!```&
M2`=+!TIX1'M$>D2#0@/0!4O36`.Q&$=P1P"_UF@!`-1H`0!69P$`"`$```A(
M"4EX1`E*>40)&GI$RP\#ZZ$!21`#T`5+TU@#L1A'<$<`OZQH`0"H:`$`*&<!
M`#0!```(M0I+"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_W1.W_][__!DL!(GM$
M&G`(O79H`0#X9@$`!`$``"IH`0!6:`$`Q.<`ORWI^$.!1A]+>T0`*#;0'DJ;
M6-/X`("X\0`/,=`%>`]&`"T8OSTM%+\!)0`E$]'8^`!`;+%&1B!&*D9)1O_W
M5NX0N6-=/2L0T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&EZPD%X>>F
MZP@&`34L1+80/F`@1KWH^(,$1N?G1$;EY[1F`0`X`0``.$HY2WI$+>GP09ZP
MTU@;:!V33_```Q"Q`W@$1F.Y,THQ2WI$TU@::!V;6D!/\``#5M$>L+WH\('_
M]U;M!48`*.W0*T]_1"A&__?R[0`H-M##?`#Q$P8N*P+1<W@`*_+0PWPN*S+0
M($;_]V[M@$8P1O_W:NU`1`(P__="[3M&3_#_,@$A`98&1@"4__=\[0*J,48#
M(/_WWNT!,#!&!=`&FP/T<$.S]8!/%]#_]^[L,$;_][#L*$;_][SM`"C(T2A&
M__?F[2!&__>R[*CG<W@N*\G1LW@`*[;0Q>?_]Y'_YN?_]\3L+&8!``P!```.
M9@$`1"0``-_X9,`92_Q$$+4$1IRP`R!<^`,P:D8A1AMH&Y-/\``#__>V[:"Y
M!)L#]'!#L_4@3QB_L_6`3PW0#4H,2WI$TU@::!N;6D!/\``#"]$<L!"]`"#Q
MYP(A($;_]U[ML/J`\$`)Z>?_]XCL-F4!``P!````90$`$+4$1O_W[.Q#'B-$
MG$(XOQI&`],JX!-&HD(GT!-&$O@!&2\I]]"<0B#2`3N<0A_0&G@O*OG1`3L#
MX!%X`3LO*0+1&D:<0OC3$AN3'+/U@%^(OP`@"=@.2"%&3_2`4P$R>$0$1O_W
M0.P@1A"]G$+BT2-X+RL%T`=(O>@00'A$__<YO`5(O>@00'A$__<SO`"_^&4!
M`*PB``!H(@``+>GP0P1&-$@.1C1)>$2M]8!=@[#?^,B0#?6`4P&O05A`]O]R
M+T@$,PEH&6!/\``!.49X1/E$__<^[+#Q``P]W0*M#/'_.$5$)TH5^`0\6?@"
M(!5H$[NX\0`/)]!"1B\A.$;_]\SL"+,H1O_W%NU#1CI&(4;_]^#L'$D-]8!3
M%TH$,WE$BE@1:!IH44!/\``"(-$-]8!=`["]Z/"#X$8O(4)&.$;_]ZKL`"C=
MT2A&__?T[#)&(4;_]_CKW><*2UGX`S`=:"A&__?H[#)&(4;_]^SKT>?_]\CK
M(&0!``P!``#X8P$`7B(``!0!``"J8P$`64I:2WI$+>GP1PQ&@K`%1M-8W_A<
M@1MH`9-/\``#"WCX1#TK"+\!-"!&__<4[&E&!D8H1O_W)/Z!1@`H5M#_]PKL
MAD))V4M+`)]8^`.`OP`K>``K&+\]*Q2_`2,`(P?0*T83^`$O`"H8OSTJ^=%;
M&[`<V/@`8!A$__?(Z_!1^+'8^``P*$8`FE/X(A`0^`$["W``*QB_/2L)T$H<
M$/@!.Q%&`O@!.STK&+\`*_;1"D8](PMP%/@!.P+X`3\`*_G1+4HJ2WI$TU@:
M:`&;6D!/\``#1M$"L+WH\(<)\?\Y%/@!.PGX`3\`*_G1Z><A2UCX`X#8^`!P
M.VB#LSM&4_@$+TE&"?$!"0`J^-$#,8D`&TIZ1!-HN[D(1@$C$V#_]W;K@D8`
M*,S0.49/ZHD'.D;_]_#JR/@`H`GQ`0,`(DKX(R#-^`"0A.<X1O_W*NN"1LCX
M````*+303^J)!^SGF48((=7G__<*ZP"_.&,!``P!```<8P$`.`$``'AB`0"L
M8P$`,+413!%+@[!\1.58*&C_]PSL*&C_]PCL#4H.2PY)>T2B6'E$__>"ZRAH
M__?^ZPM+"TH`)`M)>T1Z1,WI`#1Y1/_WGNL#L#"]M&$!`!0!```0`0``<EX`
M``X@``#.(@``20X```X@```0M0A,"$M\1.-8&&C_]]CK!DH'2P=)>T2B6'E$
MO>@00/_W3KM.80$`%`$``!`!```27@``KA\``"1),+4D2GE$K?4`78FP#?4`
M4P6LBE@<,Q)H&F!/\``"__?\ZAU)0?(!`AU+>43-Z0`!>T0!(2!&__<:ZPWU
M@%$8,2!&3_2`4@.1__>LZ@0>N+\`)0K;8!S_]\CJ!48HL0.9(D;_]U+J`",K
M50U)#?4`4PE*'#-Y1(I8$6@::%%`3_```@31*$8-]0!=";`PO?_W8NH680$`
M#`$``*0?``"2'P``IF`!`/_WJK\MZ?!/!D9E3&5*K?6$77Q$@[!D2`WUA%,&
MKP0SHE@-1GA$.482:!I@3_```O_WPOPO(01&,$;_][3JP+%:2#%&>$3_]W?^
M,$9820WUA%-42@0S>42*6!%H&FA10$_P``)`\)F`#?6$70.PO>CPCS!&__>*
MZDY)@$8H1GE$__?RZ@`HV]!+2X-&W_@LD7M$!9-*2_E$>T0$DYOX`#``*U#0
M++%91B!&__>PZ0`H5=!81O_W:NH`\?\\AD8+ZPP#&_@,("\J$-&"'JSK`PQ:
M1!A&TAI/\``*@_@`H`/K#`X31!#X`1TO*?;0"/$!`YY$OO6`7Z/:,DHAK0$A
M2T9Z1"A&S>D!)D_T@%+-^`"P__=:ZCI&*48#(/_WONHHN0J;`_1P0[/U`$\B
MT"9)`"!Y1/_WFNJ#1KOQ``^`T)OX`#``*Z[1'+,C>"XK!-#=^!2P3_`!#LGG
M8W@`*_?1&TD`('E$__>`ZH-&N_$`#^;19N<!(2A&__=LZ@`HUM$42"E&>$3_
M]]C]*$;_]XSI7>?=^!"P3_`!#JCG__>*Z0"_8F`!``P!```('P``]!X``!Y@
M`0#*'@``#!X``+8>```$'@``U!T``!@>``#F'0``MAT```-X.[%"'"\K"+\0
M1A+X`3L`*_C1<$<`OQ"Q`W@#L=OD`4AX1/_W4KFF'```W4K?^'C#WDMZ1'"U
M_$0,\0P,C+#;3M-8#?$(#GY$`:P;:`N33_```]=-O.@/`*[H#P!]1+SH#P"N
MZ`\`W/@`,*[X`#`A1C!&__>V^["QSTL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S
M6FA#^`0K`"KZT2%&,$;_]Z#[`"CHT<1.?D0A1C!&__>8^["QP$L!F.M8&6@!
MZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]X+[`"CHT;9.?D0A1C!&
M__=Z^["QL4L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_
M]V3[`"CHT:A.?D0A1C!&__=<^["QHDL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S
M6FA#^`0K`"KZT2%&,$;_]T;[`"CHT9I.?D0A1C!&__<^^["QDTL!F.M8&6@!
MZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]RC[`"CHT8Q.?D0A1C!&
M__<@^["QA$L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_
M]PK[`"CHT7Y.?D0A1C!&__<"^["Q=4L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S
M6FA#^`0K`"KZT2%&,$;_]^SZ`"CHT7!.?D0A1C!&__?D^K"Q9DL!F.M8&6@!
MZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]\[Z`"CHT6).?D0A1C!&
M__?&^K"Q5TL!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_
M][#Z`"CHT51.?D0A1C!&__>H^K"Q2$L!F.M8&6@!ZX`#6FA!^"`@`"KOT`0S
M6FA#^`0K`"KZT2%&,$;_]Y+Z`"CHT49.?D0A1C!&__>*^K"Q.4L!F.M8&6@!
MZX`#6FA!^"`@`"KOT`0S6FA#^`0K`"KZT2%&,$;_]W3Z`"CHT3A((49X1/_W
M;?H!1ABQ-DAX1/_W)_PU2"%&>$3_]V+Z`488L3)(>$3_]QS\,4@A1GA$__=7
M^@%&J+$O2'A$__<1_"Y)+DAY1'A$__<+_"U*%DMZ1--8&F@+FUI`3_```QW1
M#+!PO2A((49X1/_W.OH!1B"Q)4AX1/_W]/OAYR1)"B(-\1D`>43_]Z+H`"C8
MT2!(#?$C`7A$__?D^]'G_O>>[P"_;%X!`#Q;```,`0``.!T``$)>`0`X`0``
MXAP``*X<``!^'```2AP``!X<``""&P``LAL``((;``!2&P``GAH``.0:``#`
M&@``XAH``*89``#@&@``'!H``/H:``!@&@``3EL!`+8:``!.&@``KAH``"X:
M```72QA)&$I[1'E$`+48:(.PBEA#'!)H`9)/\``"#-`32A%+>D336!IH`9M:
M0$_P``,3T0.P7?@$^PU(:49X1/_WQ?DPL0!X,"@8OP`H%+\!(``@"$M[1!A@
MX>?^]S3O`+_&6P$`@%H!``P!``!F6@$`<!D``'A;`0`(M?[WZN[^]]SN`+$`
M:`B]+DHO2WI$\+4N3H>P!4;36'Y$!*DP1AMH!9-/\``#__>1^1"Q`W@$1HNY
M)THD2WI$TU@::`6;6D!/\``#/-$C2"E&>$0'L+WH\$#_]SN[*4;^]YSN6+$>
M2AE+>D336!IH!9M:0$_P``,FT0>P\+TH1O[W4N\'1B!&_O=.[SA$`C#^]R;O
M$TL42@$A>T0"E'I$`)4!DD_P_S($1O[W7.\/2@=+>D336!IH!9M:0$_P``,$
MOR%&,$;%T/[WP.[\60$`#`$``)09``#260$`8AD``*99`0!.&```1A@``%Y9
M`0`MZ?!/W_A,5:WU`4W?^$A%@;!]1'Q$0*\B':?Q=`,'D`WU`$'?^#0%!/$0
M#/PQ*#2G\6@.W_@HI:?QX`8H6*?Q7`7Z1`!H"&!/\```!\J#Z`<`O.@/``_%
MG.@#`(7H`P"4Z`<`CN@'`-_X^`0Q1GA$__?X^""Q`W@$1@`K0/!@@?[W,N[^
M]R3N`"@`\'&!!6@`+0#PEX$H1O[WSNY```$P_O>F[BIX@$:"L=_XO+1$1OM$
M($8`DEM&3_#_,@$A`C3^]]CN%?@!+P`J\M'?^)P$I_%8!7A$`N!5^`0+B+$Q
M1O_WP/@$1@`H]M`#>``K\]#_]WCY`"COT"!&_O<J[@1&T+E/\``)I_%T"P?K
MB0)2^'1,A+$)\0$%"^N%!2)X4K$@1@GQ`0G_]UWY`"A<T57X!$L`+/+1`"0@
M1O[W?NZ#1D!&_O=Z[EA$`/($2UA&_O=0[M_X'#1/\/\R`2%[1`*3W_@0-,WX
M#("`1GM$`9/?^`@T`)1[1/[W?NY/].!Q0$;^]XSN`3`%T?[W;NX!:!$I0/#&
M@#)&048#(/[W[.X%1DBS]DD'F_9*6O@!`$_P``H;:'I$S?@`@`$A`&C^]XSN
M\$D-]0!#Y4K\,WE$BE@1:!IH44!/\``"0/"Z@5!&#?4!30&PO>CPCR!&_O>R
M[01&`"B*T*#G5_C0/`/T<$.S]8!/SM%7^,A,_O=N[81"R-%7^-`\P_,(`[/U
MX'_!T5A&_O?F[8)&V$@Q1GA$__<:^``H`/#)@`>;'&C^]XKM`48@1O_W-?N#
M1@`H`/"]@%A&_O?R[01&`R@/V<Q)!#A81'E$_O<J[4"Y!"P`\"Z!7$04^`4\
M+RL`\"B!Q4Q\1"-H6AP`\*6``"L`\+>`P4G"2'E$W_@(DWA$P4__]Z/YP4[^
M][[MP$M/\/\R`2%[1`.3ODOY1,WX`(!_1'M$S>D!,+M+4$9^1'M$_O?4[13@
M_O?,[0-H$2L7T?[WHNT!-81&2T8B1@$A4$;-Z0-7S>D!;,WX`(#^][[M3_3@
M<5!&_O?.[01&0QSBT$!&_O?\[*E(449X1/_W9OE01O_W`?Y/YY9*!YM:^`(`
M3_``"AMHHDK-Z0"!`2%Z1`!H_O?.[3_G__?N_9U)A4H-]0!#>43\,XI8$6@:
M:%%`3_```D#P^(`@1@WU`4T!L+WH\$_^]^Z\@$:G\6@$!^N(`U/X:`S(L0CQ
M`0L$ZXL%!.!5^`0+B+$+\0$+,4;81O[W9/\`*/30`W@`*_'0_O?4[`5&`"A_
M]'*NX.>"30T@_O<:[5,B@$9]1'+FJ$;4YP>;T_@`L#[G?$@Q1GA$_O=%_P`H
M`/"*@`-X`"L8OS`K%;\!(P`C`2,C8!B_(V!_]$FO6$8`(?[W\NP$1@`H/_1!
MKT_P_S-O\!$"`B8]'P"6_O?2[`8B*48@1O[W7.P7^`0\&[D7^`,\0RMAT``C
M`"(`DR!&`"/^]\#L`?`!^`9&`^`I1C!&`?`W^$_T`$(I1B!&_O=`[`(>\]S?
M^&2Q($:G\3`)_O=\[:?Q104Q1OM$3$:G\3$&I_%$``'PB?@5^`$O($8`DEM&
M3_#_,@$A_O?N[`(TKD+RT4I*`2'-^`B04$9Z1$A+S>D`@@`B!_@(+'M$1DIZ
M1`.23_#_,O[WUNP>YP>;7&@`+#_TTZX@1O[WL.P#*'_VS:X]200X($1Y1/[W
MYNL`*`B_HT;"YB!@@.<7^`(\02N9T1?X`3Q#*Y71.WA(*Y+1>WA%*X_13_#_
M,V_P.0(@1@"6_O=.["E&*2(@1O[WV.LK2RM)3_#_,GM$S>D"4RE+>4101LWI
M`(%[1`$A_O>4[-OF_O<$[`Y9`0!06@$`#`$``-Y8`0!J%P``+!@``'@6``"4
M%P``%A8``'`7```<`0``@A<``%97`0!>%P``,!<``.A7`0`P%@``KA4```X7
M``"P%P``O!0``+P7``#&%```ZA8``,84``#"%0``U%4!`!05``!P%```9A0`
M`-82``#H%```K!4``+(4```R%0``0A(``%H4``!?2&!)>$3PM5]+@[!?2D%8
M>T1N1@EH`9%/\``!G%@@:/[WP.P%1B!H_O>\[#%&E?AH,(#X:3!62'A$_O<?
M_A"Q`W@Q*WK0__<]^B!H_O>J[%!)`R,!(GE$_O?BZP5&:+$@:/[WH.PK:4M*
M&6AZ1/[WHNLK:1MHFVA;`F[4(&C^]Y+L1DD#(P$B>43^]\KK!49XL4-(,49X
M1/[W\/T'1B!H`"]/T/[W?NPK:3I&&6C^]X+K(&C^]W;L!48@:/[W<NPX20$B
M>43^]];K-TH!1BA&>D0V3?[W;NL@:/[W9.P#1GU$,T@`(C%&>$2#^&D@_O?%
M_01&J&"PL4_TX'$@1O[WVNM"'`-&$2@8OP$J+]@I2AQ+>D336!IH`9M:0$_P
M``,CT0.P\+UH:/_W=OP$1JA@`"CAT2!(>$3^]Z[K0W@`*X/0@.?^]R[L'$LJ
M:7M$$&A;:!EH_O?:_JOG(&C^]R+L*VD9:/[WN.N(Y_[W!.L422)&%$AY1'A$
M26@):/[WC.LT4P$`#`$``"A3`0`4`0``"!(``)83``"$$P``<!,``&81```X
M$P``1!,``-A3`0`($0``)E(!`.82``!L4P$`1%,!`,H2```W2CA+>D3PM0=&
M@[#36!MH`9-/\``#`"A$T`-X`"M!T/[W0OX$1B-X.[%B'"\K"+\41A+X`3L`
M*_C1*TX]'AB_`25^1#-H6APRT``K#+\`)07P`05=N25*(DMZ1--8&F@!FUI`
M3_```SC1`[#PO3MX`"OPT!Y)!"(@1GE$_O>0ZP`HZ-$;2A=+>D336!IH`9M:
M0$_P``,AT3A&`["]Z/!`_O=.O11(>$3^]WKJ!$:ZYQ)(:49X1/[W_?QHL0-X
M`"L8OS`K"K\`(P$C,V##T`$C,V``+;_0RN<P8+SG_O=FZFQ1`0`,`0``<E(!
M`!91`0#&$```Z%`!`/(.``#@#P``+>GP3P#Q0`'?^(!+W_B`.ZWU(WU\1.Y&
M<D8`\8`,`"?C6!MHH9-/\``#4>D"9%=@UV`0,C:Z0O@0;",*)0(#]']#"#%#
MZA1C!?1_!4/J!&-A14/J!0-"^`@\YM&M\0@&#O7\=P`CA$8T1E;X"`_4Z0:%
M(F_4^$B@86_4^$R0@NH*`G1H@NH(`H'J"0%"0&E`QOB$,&%`E!C2#[Y"0NI!
M`D+J!`+&^(`@WM%@1M[X`$#<Z0,F@6C<Z0!Y3^J1#@*=3NJ"?D?VF1+%]H(B
M3NJ!?@%J3^K7;*083.I)'&08@6E,ZD<<W?@0@!SK!`2&Z@$,@6C=^*"@#.H!
M#(%IC.H!#!3K#`2&Z@X,K1@,Z@<,;1B,Z@8,%>L,#!CK`@5/ZI<(K1E(ZHEX
MW?@8D$CJAW@,Z_1LCNH(`2%`3^JT!('J#@%M&!GK`@$1ZPX!B.H$#MWX()`.
MZ@P.CNH(#@7K_&41ZPX.3^J\#!GK`@'=^"B0$>L(`83J#`@(Z@4(#NOU;HCJ
M!`A/ZK4%$>L(`1GK`@F,Z@4(&>L$!`CJ#@C=^#"0`>O^88CJ#`A/ZKX.%.L(
M!!GK`@F%Z@X(&>L,#`CJ`0C=^#B0!.OQ9(CJ!0A/ZK$!'.L(#!GK`@F.Z@$(
M&>L%!0CJ!`C=^$"0#.OT;(CJ#@A/ZK0$%>L(!1GK`@F!Z@0(&>L.#@CJ#`C=
M^$B0!>O\98CJ`0A/ZKP,'NL(#AGK`@F$Z@P(&>L!`0CJ!0C=^%"0#NOU;HCJ
M!`A/ZK4%$>L(`1GK`@F,Z@4(&>L$!`CJ#@C=^%B0`>O^88CJ#`A/ZKX.%.L(
M!!GK`@F%Z@X(&>L,#`CJ`0C=^&"0!.OQ9(CJ!0A/ZK$!'.L(#!GK`@F.Z@$(
M&>L%!0CJ!`C=^&B0#.OT;(CJ#@A/ZK0$%>L(!1GK`@F!Z@0(&>L.#@CJ#`C=
M^'"0!>O\98CJ`0A/ZKP,'NL(#AGK`@F$Z@P(&>L!`0CJ!0C=^'B0#NOU;HCJ
M!`A/ZK4%$>L(`1GK`@F,Z@4(&>L$!`CJ#@C=^("0`>O^88CJ#`A/ZKX.%.L(
M!!GK`@F%Z@X(&>L,#`CJ`0C=^(B0!.OQ9(CJ!0A/ZK$!'.L(#!GK`@F.Z@$(
M&>L%!0CJ!`C=^)"0B.H."`SK]&P5ZP@(3^JT!!GK`@DFG1GK#@Z!Z@0)">H,
M"0CK_&B)Z@$)3^J\#![K"0ZJ&%$8A.H,`@+J"`(.Z_AN8D!/ZK@%B1A.]J$R
MQO;98MWXJ(`:ZP(*`>O^81KK!`2,Z@4*BNH."D_JO@X4ZPH$W?BPD!CK`@B%
MZ@X*!.OQ9(KJ`0H8ZPP,3^JQ`=WXN(`<ZPH,&>L""8[J`0H,Z_1LBNH$"AGK
M!05/ZK0$%>L*!=WXP)`8ZP((@>H$"@7K_&6*Z@P*&.L.#D_JO`P>ZPH.W?C(
M@(3J#`H9ZP()BNH%"AGK`0D.Z_5A&>L*"4_JM048ZP(*W?C0X!KK!`H)Z_%D
MC.H%"8GJ`0E/ZK$!&NL)"A[K`@G=^-B`&>L,"0KK]&R%Z@$*BNH$"D_JM`09
MZPH)&.L""MWXX.`:ZP4*">O\98'J!`F)Z@P)3^J\#!KK"0H>ZP()W?CH@!GK
M`0D*Z_5AA.H,"HKJ!0I/ZK4%&>L*"1CK`@C=^/#@&.L$"`GK\62,Z@4)B>H!
M"4_JL0$8ZPD('NL"#MWX^*`>ZPP.A>H!#`CK]&B,Z@0,3^JT!-WX`)$>ZPP.
M&NL"#('J!`H.Z_ANBNH("ASK!0Q/ZK@('.L*#$*=A.H("AGK`@D,Z_YLBNH.
M"AGK`0E/ZKX.&>L*"429K1B(Z@X*BNH,"BP9">O\94_JO`P4ZPH$W?@8D8[J
M#`J)&`3K]62*Z@4*$>L(`4_JM041ZPH!C.H%"AGK`@D!Z_1ABNH$"MWX(($9
MZPX)3^JT"QGK"@G=^"CA">OQ9!CK`@B%Z@L)&.L,"(GJ`0E/ZK$!&.L)"-WX
M,,$>ZP(*B^H!#H[J!`X:ZP4*&NL."@CK]&4<ZP(,3^JT!-WX..$<ZPL+@>H$
M#`KK]6J,Z@4,3^JU!1OK#`P>ZP("4AB$Z@4!W?A`X8'J"@%/ZKH(41A+]MQ"
MR/8;<@SK^FP>ZP(.1>H("A[K!`0*Z@P*!>H(#MWX2)$!Z_QA2NH.#D_JO`P4
MZPX.&>L""4CJ#`0(Z@P*&>L%!0Q`W?A0D0[K\6Y$Z@H$3^JQ`649&>L""4SJ
M`009ZP@*#.H!"]WX6)$$Z@X$!>O^943J"P1/ZKX.%.L*!!GK`@D9ZPP)0>H.
M#`'J#@K=^&"!#.H%#`3K]61,Z@H,3^JU!1SK"0P8ZP((&.L!`0SK]&A.Z@4,
M#NH%"MWX:)$,Z@0,3.H*#$_JM`0<ZP$,&>L""47J!`$9ZPX*!>H$"]WX<)$!
MZ@@!3^JX#D'J"P$,Z_AL$>L*`1GK`@D9ZP4*1.H."0'K_&4)Z@P)3^J\`=WX
M>($$Z@X,2>H,#-WX@)$<ZPH,&.L""!CK!`0,Z_5H3NH!#`[J`0H,Z@4,3^JU
M!4SJ"@Q!Z@4*'.L$!!GK`@P$Z_ADW?B(D0KJ"`H<ZPX,3^JX#@'J!0A*Z@@(
M!>H."ACK#`P9ZP((1>H."1CK`0@)Z@0)9)E)Z@H)#.OT;!GK"`A/ZK0$B1@.
MZ@0)31E.Z@0!`>H,`0CK_&A!Z@D!3^J\#$T99IE$Z@P)!.H,"HD8">H("1'K
M#@YHF07K^&5)Z@H)3^JX"!GK#@F)&`SJ"`H1ZP0.">OU9$SJ"`EJF0GJ!0E/
MZK4%2>H*"1GK#@Z)&!'K#`Q(Z@4!".H%"2%`0>H)`0[K]&X1ZPP,;)E/ZK0$
M#.O^;(D81>H$"07J!`H1ZP@(">H."6Z92>H*"4_JO@X9ZP@)B1@1ZP4(">O\
M943J#@D$Z@X*<)D)Z@P)2>H*"4_JO`P9ZP@)3NH,"(D8".H%"`D9">OU9`[J
M#`E/ZK4%2.H)"$SJ!0D8ZP$(<ID,Z@4*">H$"8D8".OT:!'K#@YTF4_JM`1)
MZ@H)&>L."8D81>H$#@GK^&D1ZPP*#NH(#D_JN`QVF07J!`A#8$[J"`X$Z@P(
M'NL*#HH851E$Z@P"`NH)`GB90NH(`@[K^6Y5&4SRUA+,]F(B3^JY"1'K`@AZ
MF1CK!`B,Z@D$A.H.!`7K_F48ZP0(3^J^#HD8B>H.!!'K#`Q\F6Q`".OU:!SK
M!`Q/ZK4%B1B.Z@4$$>L)"7Z9#.OX;(3J"`09ZP0)3^JX"(P8@)D4ZPX$">O\
M;H7J"`G#8(GJ#`E/ZKP,%.L)!(D831F(Z@P)@ID$Z_YDB>H."4_JO@X5ZPD)
MC1@5ZP@%A)D)Z_1HC.H."8GJ!`E/ZK0$%>L)!8D8$>L,#([J!`F&F07K^&6)
MZ@@)0V$<ZPD)3^JX#!'K`@B(F1CK#@@)Z_5NA.H,"<-AB>H%"4_JM048ZPD(
M$>L""1GK!`F*F0CK_F2,Z@4(B.H."$_JO@X9ZP@)$>L""!CK#`B,F0GK]&R%
MZ@X)B>H$"4_JM`08ZPD($>L""1GK!0F.F0CK_&6.Z@0(B.H,"$_JO`P9ZP@)
M$>L""!CK#@B0F0GK]6Z$Z@P)B>H%"4_JM048ZPD($>L""1GK!`F2F0CK_F2,
MZ@4(B.H."$_JO@X9ZP@)$>L""!CK#`B4F0GK]&R%Z@X)B>H$"4_JM`08ZPD(
M$>L""1GK!0F6F0CK_&6.Z@0(B.H,"$_JO`P9ZP@)$>L""!CK#@B8F0GK]6Z$
MZ@P)B>H%"4_JM048ZPD(B1@1ZP0)".O^9)J9C.H%"(CJ#@A/ZKX.&>L("8D8
M$>L,"`GK]&R%Z@X)G)F)Z@0)3^JT!!CK"0B)&`CK_&A-&9Z9!NNX!@9ACNH$
M!H;J#`9/ZKP,K1F*&-<9A.H,`@7K^&47ZPX.@NH("()H'NL(#JD8#NOU8H5I
M`F`":ASK!06!8*08"TK`Z0A#"4MZ1(5ATU@::*&;6D!/\``#`]$-]2-]O>CP
MC_WWDNP`OUQ0`0`,`0``!$4!``BU@"#]]]#LG^T/>P`B@F>`[0![G^T.>X#M
M`GN?[0Y[@.T$>Y_M#GN`[09[G^T.>X#M"'N?[0Y[@.T*>X#M#'L(O0"_K_,`
M@`$C16<`````B:O-[P````#^W+J8`````'94,A``````\.'2PP``````````
M`````"WI^$,%1A9&@VH`(`Q&]Q?5Z0PA`^O&#)Q%ZVIPZP,#`])3'!I&0?$`
M`<7I"L!S#ZAO0^K'`YL8!?$X"$'K5W$K8VEC@+L_+D/=IO%`"4_JF19W'`3K
MAQ<A1D-&!/%`#M'X`,`0,5'X#$P0,U'X"`Q1^`0L<45#^!#,0_@,3$/X"`Q#
M^`0LZ]$,1BA&__>P^;Q"X=&IZX86,D8Y1D!&_??8ZZYGO>CX@\#Q0`<A1K="
M0$2HOS=&.D;]]\KKJV\[1*MG0"ONT2A&]AL\1/_WD/FYYR=&X.<`ORWI\$$!
M\3@'#$:+:@5&#FN`(9/Z@_C#\\4#-KI:'+@8."KY5$3=PO%``@`A_?=P["!&
M__=Q^3A&."(`(?WW:.P@1L3I'&C_]V?YXW@K<"!&8XAK<"-H&PJK<"-HZW#C
M>BMQ8XEK<:-H&PJK<:-HZW'C?"MR8XIK<B-I&PJK<B-IZW+C?BMS8XMK<Z-I
M&PJK<Z-IZW.4^",P*W1CC&MT(VH;"JMT(VKK=+WH\$']]UR[PO$X`@`A_?<L
M[,'G+>GX0P=&#$X,38A&?D211GU$_?<2ZW8;MA`*T`0]`"15^`0_2D9!1CA&
M`3281Z9"]M&]Z/B#`+^L00$`I$$!`'!'`+\"2WM$&VC]]V.[`+_&0P$`"$`M
MZ0B`O>@!``(`.@```#T````*````/0````\````]````)````#T````R````
M/0````(````]````!0```#T````3````/0````T````]````#````#T````C
M````/0```!$````]````)@```#T````!````/0```!<````]````"````#T`
M```)````/0``````````````+W1M<``````N````4$%27U1-4$1)4@``5$5-
M4$1)4@!435``55-%4@````!54T523D%-10`````E<R\E<P```"\````O<')O
M8R]S96QF+V5X90``1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`````"]P<F]C+R5I+R5S`&5X90!005)?5$5-4```
M``!005)?4%)/1TY!344`````.@```"5S)7,E<P``4$523#5,24(`````4$52
M3$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%1`!005)?
M4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!0
M05)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0``
M`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````)7,E<R5S)7,`````
M<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@`````E<R5S
M8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`
M````&````'!E<FP`````,````%!!4CHZ4&%C:V5R.CI615)324].`````#$N
M,#4R````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z
M(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@`````M90``+2T``&5V86P@)V5X96,@+W5S<B]B
M:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG
M('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?
M34%'24,L("1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L
M94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E
M($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@
M1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N
M86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P
M87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@
M*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?
M=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2![
M"FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A8
M6%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I
M+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N
M86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ
M.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G
M"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E
M<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*
M8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@
M(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["F5V86P@>PI?<&%R7VEN
M:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#
M;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P
M96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64@;W(@;&%S=#L*;7D@)&)U9CL*
M;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S:7IE(#T@-C0@
M*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@)&-H=6YK7W-I
M>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D;2`]("1S:7IE
M("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@)'-I>F4@+2`D
M;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H=6YK7W-I>F4[
M"GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K(%]&2"P@)&UA9VEC
M7W!O<RP@,#L*<F5A9"!?1D@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["B1M86=I8U]P;W,@*ST@)&D["FQA<W0["GT*)&UA
M9VEC7W!O<R`M/2`D8VAU;FM?<VEZ93L*?0IL87-T(&EF("1M86=I8U]P;W,@
M/"`P.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0L(#`["G)E860@7T9(+"`D
M8G5F+"`T.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M(#0@+2!U;G!A8VLH(DXB
M+"`D8G5F*2P@,#L*)&1A=&%?<&]S(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97T@/0HD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L
M"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&
M2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@
M)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D
M=6QE.PIM>2`D:6YF;R`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M(&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN
M;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P
M+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["F]P96X@
M;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E
M860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S
M=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2([
M"GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A
M=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@
M24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R
M97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R
M("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL
M87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@
M;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM
M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)
M3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P87(B73L*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D
M<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#
M86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D
M("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL
M95T@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PIC;&]S92`D<&@["GT*
M0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O
M=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]74D].3%DH
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1D871A
M7W!O<RD@>PIR96%D(%]&2"P@)&QO861E<BP@)&1A=&%?<&]S.PI](&5L<V4@
M>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*9F]R96%C
M:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;
M)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B
M7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD
M;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G
M('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP
M<FEN="@D;&]A9&5R*3L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE
M879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC
M*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$
M4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\
M?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`
M1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@
M("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N
M86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*
M?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^
M(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO
M*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D
M9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT
M(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N
M9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ
M<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI
M('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O
M(#T@=6YD968["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@
M<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1F:#X[
M"F-L;W-E("1F:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O
M;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE
M;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*3L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE
M*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA
M;64L(#`L(#0P.PII9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H
M,2D["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D;W5T.PHD8W1X+3YA9&1F:6QE
M*"1F:"D["F-L;W-E("1F:#L*)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E
M<W0["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@D4$%27TU!1TE#*3L*
M)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR
M97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI[
M"G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD
M;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D
M;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II
M<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2)=*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO
M=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B72D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U
M:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A
M='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I
M<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V
M86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@
M<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q
M=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![
M(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E
M9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H
M+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@
M)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@
M5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@
M>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W
M=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F
M:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E
M<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%
M4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE
M(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E
M;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR
M87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M
M92(Z("0A73L*<V5E:R`D9F@L("TQ."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L
M("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F:"P@
M+34X+"`R.PIR96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+21B=68B.PI]"F5L
M<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I<F4@1&EG97-T.CI32$$[
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@
M(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O
M9VYA;64B.B`D(5T["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*
M96QS92!["B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP
M9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE
M(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N86UE(CH@)"%=.PIP<FEN
M="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@
M*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X
M97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O
M;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M921#;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@
M/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H
M9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F
M:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D
M8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#
M;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM0
M05)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV
M('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U
M<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R
M("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%
M("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U0
M1$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/
M0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!
M4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]
M("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@
M;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@
M)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B
M(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D
M969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E
M>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R
M8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E
M(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP
M;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R
M;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O
M<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%
M.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID
M:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%
M.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$
M7U\*``!P97)L>'-I+F,```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@(``````Z````/0````H````]````#P```#T````D````/0```#(````]
M`````@```#T````%````/0```!,````]````#0```#T````,````/0```",`
M```]````$0```#T````F````/0````$````]````%P```#T````(````/0``
M``D````]``````````````"<FO]_`0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````1@`
M`,$7```!````*`,```$````X`P```0```$@#```!````4@,```P````L$@``
M#0```$@\```9````K'T!`!L````$````&@```+!]`0`<````!````/7^_V^T
M`0``!0```%0)```&````I`(```H```#:!```"P```!`````5``````````,`
M``#$?@$``@```.@!```4````$0```!<```!$$```$0```&0/```2````X```
M`!,````(````'@````@```#[__]O`0``"/[__V\$#P``____;P,```#P__]O
M+@X``/K__V\0````````````````````````````````````````````````
M`````````+1]`0```````````#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(`
M`#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``
M.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X
M$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2
M```X$@``.!(``#@2```X$@``.!(``#@2```X$@``.!(``#@2```U/```````
M``````````````````````````````````````#U.P```````#D5````````
M````````````````!(`!`/_____D/```[#P```````#P/```]#P``/P\``"`
M/0``!#T````````(/0``$#T````````80```1T-#.B`H1&5B:6%N(#$P+C(N
M,2TV*2`Q,"XR+C$@,C`R,3`Q,3``03(```!A96%B:0`!*`````4W+4$`!@H'
M00@!"0(*!!($$P$4`14!%P,8`1D!&@(<`2(!`"YS:'-T<G1A8@`N:6YT97)P
M`"YN;W1E+F=N=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%2
M32YE>&ED>``N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y
M;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E
M<P````````````````````````````````````````````````````````L`
M```!`````@```%0!``!4`0``&0```````````````0`````````3````!P``
M``(```!P`0``<`$``"0```````````````0`````````)@````<````"````
ME`$``)0!```@```````````````$`````````#0```#V__]O`@```+0!``"T
M`0``\`````4`````````!`````0````^````"P````(```"D`@``I`(``+`&
M```&`````P````0````0````1@````,````"````5`D``%0)``#:!```````
M```````!`````````$X```#___]O`@```"X.```N#@``U@````4`````````
M`@````(```!;````_O__;P(````$#P``!`\``&`````&`````P````0`````
M````:@````D````"````9`\``&0/``#@````!0`````````$````"````',`
M```)````0@```$00``!$$```Z`$```4````5````!`````@```!\`````0``
M``8````L$@``+!(```P```````````````0`````````=P````$````&````
M.!(``#@2`````P`````````````$````!````((````!````!@```#@5```X
M%0``$"<`````````````"`````````"(`````0````8```!(/```2#P```@`
M``````````````0`````````C@````$````"````4#P``%`\```(0```````
M```````$`````````)8````!``!P@@```%A\``!8?```"`````T`````````
M!`````````"A`````0````(```!@?```8'P```0```````````````0`````
M````JP````X````#````K'T!`*Q]```$```````````````$````!````+<`
M```/`````P```+!]`0"P?0``!```````````````!`````0```##````!@``
M``,```"T?0$`M'T``!`!```&``````````0````(````S`````$````#````
MQ'X!`,1^```\`0`````````````$````!````-$````!`````P````"``0``
M@```0```````````````!`````````#7````"`````,```!`@`$`0(```!00
M``````````````0`````````W`````$````P`````````$"````G````````
M```````!`````0```.4````#``!P``````````!G@```,P``````````````
M`0`````````!`````P``````````````FH```/4```````````````$`````
#````
